function love.load()

	-- geometry	
	width, height = love.graphics.getDimensions()
	lineWidth = height/54
  b1x = width-height/5
  b1y = height/5
  b2x = width-height/5
  b2y = 4*height/5
  br = height/8
  bl = height/15
  
  -- parameters (physical and time)
	counter = 0
	timer = 0
	b1Timer = 0
	b2Timer = 0
	buttonTime = 0.2
	cycle = 20
	temperature = 0
	heating = false
	heat = 0
	heatUp = 0.1
	heatDown = 0.25
	temperatureUp = 3
	temperatureDown = 0.03
	
	-- font and image
	font = love.graphics.newFont("dseg7_bold.ttf",height/27*8)
	fontSmall = love.graphics.newFont("dseg7_bold.ttf",height/27)
	fontHeight = font:getHeight()
	
	image = love.graphics.newImage('ceran.png')
	iw,ih = image:getDimensions()
	iScale = height/iw
	imageAngle = love.math.random()*math.pi*2

	-- colors
	colorOn = {240,9,37,255}
	colorOff = {72,18,18,255}
	colorWhite = {240,240,240,255}
	colorBlack = {0,0,0,255}
	love.graphics.setBackgroundColor(colorBlack)
end

function pyth(dx,dy) -- pythagorean distance
	return math.sqrt(dx^2+dy^2)
end

function love.touchpressed(id,x,y) -- touch event
	local dx,dy = x-b1x,y-b1y
	if pyth(dx,dy) < br then
		counter = math.min(counter + 1,9)
		b1Timer = buttonTime
	end
	
	dx,dy = x-b2x,y-b2y
	if pyth(dx,dy) < br then
		counter = math.max(counter - 1,0)
		b2Timer = buttonTime
	end
end


function love.keypressed(key)
	if key == 'up' then
		counter = math.min(counter + 1,9)
		b1Timer = buttonTime
	elseif key == 'down' then
		counter = math.max(counter - 1,0)
		b2Timer = buttonTime
	end
	
end

function love.update(dt)
	-- update timers
	timer = timer + dt
	b1Timer = math.max(b1Timer - dt,0)
	b2Timer = math.max(b2Timer - dt,0)
	
	-- target temperature
	target = counter * 10

	-- exponential cooling
	temperature = temperature * math.exp(-temperatureDown *dt)
	-- linear heating
	if heating then
		temperature = temperature + temperatureUp*dt
	end

	-- temperature control	
	if temperature > target + 5 or target == 0 then
			heating = false
	end

	if temperature < target - 5 then
			heating = true
	end
	
	-- determine "strength" of heating
	if heating then
		heat = math.min(heat + dt/heatUp,1)
	else
		heat = math.max(heat - dt/heatDown,0)
	end
end

function love.draw()

	-- ceran plate
	alpha = math.max(heat*255,temperature)
	love.graphics.setColor(255,255,255,alpha)
	love.graphics.draw(image,height/2,height/2,imageAngle,iScale,iScale,iw/2,ih/2)
	
	-- white circles
	love.graphics.setLineWidth(lineWidth)
	love.graphics.setColor(colorWhite)
	love.graphics.circle('line',height/2,height/2,height/2/1.15)
	
	love.graphics.setLineWidth(lineWidth/3)
	love.graphics.setColor(colorBlack)
	love.graphics.circle('line',height/2,height/2,height/2/1.15)

  -- highlights
	love.graphics.setColor(colorWhite[1],colorWhite[2],colorWhite[3],255*b1Timer/buttonTime)
	love.graphics.circle('fill',b1x,b1y,br)
	love.graphics.setColor(colorWhite[1],colorWhite[2],colorWhite[3],255*b2Timer/buttonTime)
	love.graphics.circle('fill',b2x,b2y,br)
  
  -- buttons
  love.graphics.setLineWidth(lineWidth)
  love.graphics.setColor(colorWhite)
  love.graphics.circle('line',b1x,b1y,br)
  love.graphics.circle('line',b2x,b2y,br)
  love.graphics.line(b1x-bl,b1y,b1x+bl,b1y)
  love.graphics.line(b1x,b1y-bl,b1x,b1y+bl)
  love.graphics.line(b2x,b2y-bl,b2x,b2y+bl)
  
  -- text
	love.graphics.setFont(font)
  love.graphics.rotate(-math.pi/2)
  love.graphics.setColor(colorOff)
  love.graphics.printf('8',-height,b1x-0.35*fontHeight,height,'center')
  love.graphics.setColor(colorOn)
  love.graphics.printf(counter,-height,b1x-0.35*fontHeight,height,'center')
  
  -- debug text
--  love.graphics.origin()
--	love.graphics.setFont(fontSmall)
--	love.graphics.print(math.floor(temperature*10)/10,10,10)
--	love.graphics.print(target,10,40)

end
